Sysinfo

Struct Sysinfo 

pub struct Sysinfo { /* private fields */ }
Available on crate feature si only.
The VERGEN_SYSINFO_* configuration features

VariableSample
VERGEN_SYSINFO_NAMEManjaro Linux
VERGEN_SYSINFO_OS_VERSIONLinux Manjaro Linux
VERGEN_SYSINFO_USERYoda
VERGEN_SYSINFO_TOTAL_MEMORY33 GB
VERGEN_SYSINFO_CPU_VENDORAuthentic AMD
VERGEN_SYSINFO_CPU_CORE_COUNT8
VERGEN_SYSINFO_CPU_NAMEcpu0,cpu1,cpu2,cpu3,cpu4,cpu5,cpu6,cpu7
VERGEN_SYSINFO_CPU_BRANDAMD Ryzen Threadripper 1900X 8-Core Processor
VERGEN_SYSINFO_CPU_FREQUENCY3792

Example

Emit all sysinfo instructions

let si = Sysinfo::all_sysinfo();
Emitter::default().add_instructions(&si)?.emit()?;

Emit some of the sysinfo instructions

let si = Sysinfo::builder().os_version(true).cpu_core_count(true).build();
Emitter::default()
    .add_instructions(&si)?
    .emit()?;

Override output with your own value

temp_env::with_var("VERGEN_SYSINFO_NAME", Some("this is the name I want output"), || {
    let result = || -> Result<()> {
        let si = Sysinfo::all_sysinfo();
        Emitter::default().add_instructions(&si)?.emit()?;
        Ok(())
    }();
    assert!(result.is_ok());
});

Example

This feature also recognizes the idempotent flag.

let si = Sysinfo::all_sysinfo();
Emitter::default().idempotent().add_instructions(&si)?.emit()?;

Example

Use refresh_kind to minimize the amount of data that sysinfo refreshes.

let refresh_kind = RefreshKind::nothing();
let cpu_refresh_kind = CpuRefreshKind::everything()
    .without_cpu_usage()
    .without_frequency();
let si = Sysinfo::builder()
    .cpu_brand(true)
    .refresh_kind(refresh_kind.with_cpu(cpu_refresh_kind))
    .build();
let config = Emitter::default()
    .add_instructions(&si)?
    .emit()?;

The above will always generate the following output

cargo:rustc-env=VERGEN_SYSINFO_NAME=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_OS_VERSION=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_USER=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_TOTAL_MEMORY=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_CPU_VENDOR=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_CPU_CORE_COUNT=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_CPU_NAME=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_CPU_BRAND=VERGEN_IDEMPOTENT_OUTPUT
cargo:rustc-env=VERGEN_SYSINFO_CPU_FREQUENCY=VERGEN_IDEMPOTENT_OUTPUT
cargo:warning=VERGEN_SYSINFO_NAME set to default
cargo:warning=VERGEN_SYSINFO_OS_VERSION set to default
cargo:warning=VERGEN_SYSINFO_USER set to default
cargo:warning=VERGEN_SYSINFO_TOTAL_MEMORY set to default
cargo:warning=VERGEN_SYSINFO_CPU_VENDOR set to default
cargo:warning=VERGEN_SYSINFO_CPU_CORE_COUNT set to default
cargo:warning=VERGEN_SYSINFO_CPU_NAME set to default
cargo:warning=VERGEN_SYSINFO_CPU_BRAND set to default
cargo:warning=VERGEN_SYSINFO_CPU_FREQUENCY set to default
cargo:rerun-if-changed=build.rs
cargo:rerun-if-env-changed=VERGEN_IDEMPOTENT
cargo:rerun-if-env-changed=VERGEN_DEFAULT_ON_ERROR
cargo:rerun-if-env-changed=SOURCE_DATE_EPOCH

Implementations

Source

impl Sysinfo

pub fn builder() -> SysinfoBuilder

Create an instance of Sysinfo using the builder syntax

Source

impl Sysinfo

pub fn all_sysinfo() -> Sysinfo

Enable all of the VERGEN_SYSINFO_* options

pub fn all() -> SysinfoBuilder

Convenience method to setup the Sysinfo builder with all of the VERGEN_SYSINFO_* instructions on